# Generated by ariadne-codegen
# Source: operations.graphql

from pydantic import Field

from .base_model import BaseModel
from .fragments import SubscriptionInvoicePreviewFragment


class PreviewNextInvoice(BaseModel):
    preview_next_invoice: "PreviewNextInvoicePreviewNextInvoice" = Field(
        alias="previewNextInvoice"
    )


class PreviewNextInvoicePreviewNextInvoice(SubscriptionInvoicePreviewFragment):
    pass


PreviewNextInvoice.model_rebuild()



# Generated by ariadne-codegen
# Source: operations.graphql

from typing import List

from pydantic import Field

from .base_model import BaseModel
from .fragments import CreditGrantFragment, PageInfoFragment


class GetCreditGrants(BaseModel):
    credit_grants: "GetCreditGrantsCreditGrants" = Field(alias="creditGrants")


class GetCreditGrantsCreditGrants(BaseModel):
    page_info: "GetCreditGrantsCreditGrantsPageInfo" = Field(alias="pageInfo")
    edges: List["GetCreditGrantsCreditGrantsEdges"]
    total_count: int = Field(alias="totalCount")


class GetCreditGrantsCreditGrantsPageInfo(PageInfoFragment):
    pass


class GetCreditGrantsCreditGrantsEdges(BaseModel):
    node: "GetCreditGrantsCreditGrantsEdgesNode"


class GetCreditGrantsCreditGrantsEdgesNode(CreditGrantFragment):
    pass


GetCreditGrants.model_rebuild()
GetCreditGrantsCreditGrants.model_rebuild()
GetCreditGrantsCreditGrantsEdges.model_rebuild()
